| details_ordinal_reg_polr | R Documentation |
MASS::polr() fits a cumulative-link ordinal regression model.
For this engine, there is a single mode: classification
This model has no tuning parameters.
The ordered extension package is required to fit this model.
library(ordered)
ordinal_reg() %>%
set_engine("polr") %>%
set_mode("classification") %>%
translate()
## Ordinal Regression Model Specification (classification) ## ## Computational engine: polr ## ## Model fit template: ## MASS::polr(formula = missing_arg(), data = missing_arg(), weights = missing_arg())
Bürkner P-C, Vuorre M. 2019. Ordinal Regression Models in Psychology: A Tutorial. Advances in Methods and Practices in Psychological Science 2(1):77-101. .
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.