linear_reg() defines a model that can predict numeric values from
predictors using a linear function. This function can fit regression models.
Rd parsnip:::make_engine_list("linear_reg")
More information on how parsnip is used for modeling is at https://www.tidymodels.org/.
Arguments
- mode
A single character string for the type of model. The only possible value for this model is "regression".
- engine
A single character string specifying what computational engine to use for fitting. Possible engines are listed below. The default for this model is
"lm".- penalty
A non-negative number representing the total amount of regularization (specific engines only).
- mixture
A number between zero and one (inclusive) denoting the proportion of L1 regularization (i.e. lasso) in the model.
mixture = 1specifies a pure lasso model,mixture = 0specifies a ridge regression model, and0 < mixture < 1specifies an elastic net model, interpolating lasso and ridge.
Available for specific engines only.
Details
This function only defines what type of model is being fit. Once an engine
is specified, the method to fit the model is also defined. See
set_engine() for more on setting the engine, including how to set engine
arguments.
The model is not trained or fit until the fit() function is used
with the data.
Each of the arguments in this function other than mode and engine are
captured as quosures. To pass values
programmatically, use the injection operator like so:
value <- 1
linear_reg(argument = !!value)Examples
show_engines("linear_reg")
#> # A tibble: 9 × 2
#> engine mode
#> <chr> <chr>
#> 1 lm regression
#> 2 glm regression
#> 3 glmnet regression
#> 4 stan regression
#> 5 spark regression
#> 6 keras regression
#> 7 keras3 regression
#> 8 brulee regression
#> 9 quantreg quantile regression
linear_reg()
#> Linear Regression Model Specification (regression)
#>
#> Computational engine: lm
#>