model_arg_exists: Check if a model argument is already registered

View source: R/aaa_models.R

model_arg_existsR Documentation

Check if a model argument is already registered

Description

This function checks whether a specific argument has already been registered for a model-engine combination. This is useful for extension packages that want to avoid re-registering arguments that parsnip has already registered.

Usage

model_arg_exists(model, eng, parsnip, original)

Arguments

model

A character string for the model type (e.g., "rand_forest").

eng

A character string for the engine.

parsnip

A character string for the parsnip argument name.

original

A character string for the original engine argument name.

Value

A logical value indicating whether the argument is already registered.


parsnip documentation built on May 14, 2026, 5:08 p.m.