Instead of building a keras3 model sequentially, keras3_mlp can be used
to create a feedforward network with a single hidden layer. Regularization
is via either weight decay or dropout.
Usage
keras3_mlp(
x,
y,
hidden_units = 5,
penalty = 0,
dropout = 0,
epochs = 20,
activation = "softmax",
seed = sample.int(10^5, size = 1),
...
)Arguments
- x
A data frame or matrix of predictors.
- y
A vector (factor or numeric) or matrix (numeric) of outcome data.
An integer for the number of hidden units.
- penalty
A non-negative real number for the amount of weight decay. Either this parameter or
dropoutcan be specified.- dropout
The proportion of parameters to set to zero. Either this parameter or
penaltycan be specified.- epochs
An integer for the number of passes through the data.
- activation
A character string for the type of activation function between layers.
- seed
A single positive integer to control randomness.
- ...
Additional named arguments to pass to
keras3::compile()orkeras3::fit().