ordinal_reg() defines a generalized linear model that predicts an ordinal
outcome. This function can fit classification models.
There are different ways to fit this model, and the method of estimation is chosen by setting the model engine. The engine-specific pages for this model are listed below.
¹ The default engine. ² Requires a parsnip extension package.More information on how parsnip is used for modeling is at https://www.tidymodels.org/.
Usage
ordinal_reg(
mode = "classification",
ordinal_link = NULL,
odds_link = NULL,
penalty = NULL,
mixture = NULL,
engine = "polr"
)Arguments
- mode
A single character string for the prediction outcome mode. The only possible value for this model is "classification".
- ordinal_link
The ordinal link function.
- odds_link
The odds or probability link function.
- penalty
A non-negative number representing the total amount of regularization (specific engines only).
- mixture
A number between zero and one (inclusive) denoting the proportion of L1 regularization (i.e. lasso) in the model.
mixture = 1specifies a pure lasso model,mixture = 0specifies a ridge regression model, and0 < mixture < 1specifies an elastic net model, interpolating lasso and ridge.
Available for specific engines only.
- engine
A single character string specifying what computational engine to use for fitting. Possible engines are listed below. The default for this model is
"polr".
Details
This function only defines what type of model is being fit. Once an engine
is specified, the method to fit the model is also defined. See
set_engine() for more on setting the engine, including how to set engine
arguments.
The model is not trained or fit until the fit() function is used
with the data.
Each of the arguments in this function other than mode and engine are
captured as quosures. To pass values
programmatically, use the injection operator like so:
value <- 1
ordinal_reg(argument = !!value)Ordinal regression models include cumulative, sequential, and adjacent structures.
Examples
show_engines("ordinal_reg")
#> # A tibble: 0 × 2
#> # ℹ 2 variables: engine <chr>, mode <chr>
ordinal_reg(mode = "classification")
#> ! parsnip could not locate an implementation for `ordinal_reg`
#> classification model specifications.
#> ℹ The parsnip extension package ordered implements support for this
#> specification.
#> ℹ Please install (if needed) and load to continue.
#> Ordinal Regression Model Specification (classification)
#>
#> Computational engine: polr
#>