| ordinal_reg | R Documentation |
ordinal_reg() defines a generalized linear model that predicts an ordinal
outcome. This function can fit classification models.
Rd parsnip:::make_engine_list("ordinal_reg")
More information on how parsnip is used for modeling is at https://www.tidymodels.org/.
ordinal_reg(
mode = "classification",
ordinal_link = NULL,
odds_link = NULL,
penalty = NULL,
mixture = NULL,
engine = "polr"
)
mode |
A single character string for the prediction outcome mode. The only possible value for this model is "classification". |
ordinal_link |
The ordinal link function. |
odds_link |
The odds or probability link function. |
penalty |
A non-negative number representing the total amount of regularization (specific engines only). |
mixture |
A number between zero and one (inclusive) denoting the proportion of L1 regularization (i.e. lasso) in the model.
Available for specific engines only. |
engine |
A single character string specifying what computational engine
to use for fitting. Possible engines are listed below. The default for this
model is |
This function only defines what type of model is being fit. Once an engine
is specified, the method to fit the model is also defined. See
set_engine() for more on setting the engine, including how to set engine
arguments.
The model is not trained or fit until the fit() function is used
with the data.
Each of the arguments in this function other than mode and engine are
captured as quosures. To pass values
programmatically, use the injection operator like so:
value <- 1 ordinal_reg(argument = !!value)
Ordinal regression models include cumulative, sequential, and adjacent structures.
https://www.tidymodels.org, Tidy Modeling with R, searchable table of parsnip models
Rd parsnip:::make_seealso_list("ordinal_reg")
show_engines("ordinal_reg")
ordinal_reg(mode = "classification")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.